function PlotFragility(grp,EQ,DATA,xname,yname,fit)
%PlotFragility(grp,DATA,xname,yname,fit) Plots structural demand hazard curve
%   Kevin Mackie, 2002/06/06
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   NOTE: only works with Punder load at the moment!
%
%   INPUT: grp (Ax2|3) matrices of data in linear space
%          A corresponds to total number of input files considered
%          1st column is x (DM), 2nd column y (IM)
%          EQ number of earthquake bins sent in
%          DATA array of information about group and type
%          xname label for x-axis
%          yname label for y-axis
%          fit 1 linear 2 bilinear
%
% Interpolation functions are fitting the DM given the IM (ie, y given x)
% but don't be fooled by the "reversed" axis plotting of these measures
% Output linear fits are of form log(DM)=A+B log(IM)
%
% Plots the fragility curve for the IM-EDP pair selected.  The limit state
% value for the EDP selected is prompted for.

[m,n]=size(grp);

[xylog,linexlog,lineylog,Fits,Dispersion,ssig]=FitData(grp,fit,EQ);

% output to command line
Fits
Dispersion

ymax=0;
ymin=1e6;
for k=1:n,
   if max(lineylog{k}) > ymax
      ymax=max(lineylog{k});
   end;
   if min(lineylog{k}) < ymin
      ymin=min(lineylog{k});
   end;
end;

incr=ymax-ymin;
y=ymin:incr/100:ymax;
vedp=ones(length(y),n);
vedp2=ones(length(y),n);

% note: dialog input must contain a sign as well as a number
% first character will be read as an operator, the rest as LS value
prompt='Enter limit state value:';
titl='Fragility Limit State';
def={'>2'};
answer=inputdlg(prompt,titl,1,def);
ls=answer{1};
lsval=str2num(ls(2:length(ls)));

for i=1:n,
   a=Fits(i,2);
   b=Fits(i,1);

   [mm,nn]=size(Fits);
   if nn == 4,    % bilinear fit
      a2=Fits(i,4);
      b2=Fits(i,3);
   end;
   
   sig=Dispersion(i);
   for j=1:length(y),
	  switch ls(1)
	  case '<',
	     % this gives the prob of finding < LS
         vedp(j,i)=logncdf(lsval,a+b*log(y(j)),sig);
		 if nn == 4,    % bilinear fit
            vedp2(j,i)=logncdf(lsval,a2+b2*log(y(j)),sig);
	     end;
	  case '>',	 
  	     % this gives the prob of finding > LS
	     vedp(j,i)=1-logncdf(lsval,a+b*log(y(j)),sig);
	     if nn == 4,    % bilinear fit
            vedp2(j,i)=1-logncdf(lsval,a2+b2*log(y(j)),sig);
	     end;
	  end;
   end;
end;

vedp=min(vedp,vedp2);

HH = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUI
axes(HH);						    % make them current

clrs='brmgcykbrmgcy';
lins='-------------';
wids=0.5:0.5:0.5*(n-1)+0.5;

logplot='H=plot(';
legplot='legend(';
for k=1:n,
   logplot=sprintf('%sy,vedp(:,%i),''%c%c''',logplot,k,clrs(k),lins(k));
   legplot=sprintf('%sstrcat(DATA.name,''='',num2str(DATA.vals(%i)))',legplot,k);
   if k<n,
      logplot=sprintf('%s, ',logplot);
	  legplot=sprintf('%s, ',legplot);
   end;
end

logplot=sprintf('%s);',logplot);
legplot=sprintf('%s,4);',legplot);

eval(logplot);
axis([0 max(y) 0 1]);
set(H,'MarkerSize',4);
addl=get(HH,'Children');
cntr=1;
for k=1:length(addl),
   if strcmp(get(addl(k),'Type'),'line')
      if and(~strcmp(get(addl(k),'LineStyle'),'none'), ...
	  	    ~strcmp(get(addl(k),'LineStyle'),'-.'));
	     set(addl(k),'LineWidth',wids(cntr));
		 cntr=cntr+1;
	  end;
   end;
end;
grid on;
xlabel(yname);
title('Fragility Curve');
ylabel(sprintf('P[%s %c LS=%.2f]',xname,ls(1),lsval));
eval(legplot);
set(HH,'Tag','Axes1');
