function PlotSDHC(grp,EQ,DATA,xname,yname,fit,addsig)
%PlotSDHC(grp,DATA,xname,yname,fit) Plots structural demand hazard curve
%   Kevin Mackie, 2002/04/15
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   NOTE: only works with Sa at the moment!
%
%   INPUT: grp (Ax2|3) matrices of data in linear space
%          A corresponds to total number of input files considered
%          1st column is x (DM), 2nd column y (IM)
%          EQ number of earthquake bins sent in
%          DATA array of information about group and type
%          xname label for x-axis
%          yname label for y-axis
%          fit 1 linear 2 bilinear
%          addsig 1 mean only 2 mean+1 sigma
%
% Interpolation functions are fitting the DM given the IM (ie, y given x)
% but don't be fooled by the "reversed" axis plotting of these measures
% Output linear fits are of form log(DM)=A+B log(IM)
%
% Plots the IM DM relationship showing sensitivity of the relationship
% to design parameters.  Parameters can be varied up to 16 values.

[m,n]=size(grp);

[xylog,linexlog,lineylog,Fits,Dispersion,ssig]=FitData(grp,fit,EQ);

% output to command line
Fits
Dispersion

for k=1:n,
   T(k,1)=grp{k}.v(1,3);
   T(k,2)=grp{k}.v(1,4);
end;

% Note, SDHC only currently works with Sa, any other IM will give
% bogus results
[Sa2,Sa5]=GetHazard(T(:,1),T(:,2),1);

ka=-log10(2.5380)./(log10(Sa5)-log10(Sa2));
k0=4.0397e-4./(Sa2.^(-ka));

ymax=0;
ymin=1e6;
for k=1:n,
   if max(linexlog{k}) > ymax
      ymax=max(linexlog{k});
   end;
   if min(linexlog{k}) < ymin
      ymin=min(linexlog{k});
   end;
end;

incr=ymax-ymin;
y=ymin:incr/100:ymax;
vedp=zeros(length(y),n);
vedp2=zeros(length(y),n);
for i=1:n,
   a=exp(Fits(i,2));
   b=Fits(i,1);
   sig=Dispersion(i);
   vedp(:,i)=(k0(i) * ((y/a).^(1/b)).^(-ka(i))* ...
   		exp(1/2*ka(i)^2/b^2*sig^2))';
   
   [mm,nn]=size(Fits);
   if nn == 4,    % bilinear fit
      a2=exp(Fits(i,4));
      b2=Fits(i,3);
      vedp2(:,i)=(k0(i) * ((y/a2).^(1/b2)).^(-ka(i))* ...
   		exp(1/2*ka(i)^2/b2^2*sig^2))';
   end;
end;

vedp=max(vedp,vedp2);

HH = findobj('Tag','Axes1');     	% axes must be named Axes1 in GUI
axes(HH);						    % make them current

clrs='brmgcykbrmgcy';
lins='-------------';
wids=0.5:0.5:0.5*(n-1)+0.5;

logplot='H=semilogy(';
legplot='legend(';
for k=1:n,
   logplot=sprintf('%sy,vedp(:,%i),''%c%c''',logplot,k,clrs(k),lins(k));
   legplot=sprintf('%sstrcat(DATA.name,''='',num2str(DATA.vals(%i)))',legplot,k);
   if k<n,
      logplot=sprintf('%s, ',logplot);
	  legplot=sprintf('%s, ',legplot);
   end;
end

logplot=sprintf('%s);',logplot);
legplot=sprintf('%s,3);',legplot);

eval(logplot);
axis([0 max(y) 0.0001 10]);
set(H,'MarkerSize',4);
addl=get(HH,'Children');
cntr=1;
for k=1:length(addl),
   if strcmp(get(addl(k),'Type'),'line')
      if and(~strcmp(get(addl(k),'LineStyle'),'none'), ...
	  	    ~strcmp(get(addl(k),'LineStyle'),'-.'));
	     set(addl(k),'LineWidth',wids(cntr));
		 cntr=cntr+1;
	  end;
   end;
end;
grid on;
xlabel(xname);
title('Median Structural Demand Hazard Curve');
ylabel('MAF v(EDP_m_e_d_i_a_n > y)');
eval(legplot);
set(HH,'Tag','Axes1');

vax=axis;

% add sigma info to plot
siginf='\sigma=';
for k=1:n,
   siginf=sprintf('%s%1.2f',siginf,Dispersion(k));
   if k<n,
      siginf=sprintf('%s, ',siginf);
   end;
end;
tboxx=vax(2)-(vax(2)-vax(1))/3;
tboxy=vax(4)-(vax(4)-vax(3))/500;
TT=text(tboxx,tboxy,siginf);
set(TT,'Tag','sigma');
set(TT,'FontSize',9);
set(TT,'VerticalAlignment','top');
